# DESeq2

## Libraries

library("DESeq2")
library("tximport")
library("rhdf5")
library("ggplot2")

## In-and-out

inKallistoResults <- "../../runs/kallisto/kallisto_results"
inMetadataFile <- "../../runs/merged_isa_metadata/out/merged_isa.tsv"
inMetadataSample <- "Source.Name"
inMetadataFactor <- "Factor..Photosynthesis.mode."

### Read arguments from CLI

args <- commandArgs(trailingOnly = T)

inKallistoResults <- args[1]
inMetadataFile <- args[2]
inMetadataSample <- args[3]
inMetadataFactor <- args[4]

## Import kallisto count data

files <- dir(inKallistoResults, recursive = T, full.names = T ,"abundance.h5")
names(files) <- dir(inKallistoResults)

txi <- tximport(files, type = "kallisto", txOut = TRUE)

head(txi$counts)

## Read sample metadata

samples_metadata <- read.table(file = inMetadataFile, sep = "\t")

samples <- samples_metadata[order(samples_metadata[[inMetadataSample]]), c(inMetadataSample, inMetadataFactor)]
colnames(samples)[1:2] <- c("sampleID", "condition")

rownames(samples) <- samples$sampleID

## DESeq

dds <- DESeqDataSetFromTximport(txi, colData = samples, design = ~ condition)

dds <- DESeq(dds)

## Outputs

### Extract results

res <- results(dds)
write.csv(res, file = "results_stats.csv", append = FALSE, quote = TRUE)

### Generate and save default plots

png("results_ma-plot.png")
  plotMA(res, ylim=c(-2,2))
dev.off()

vsd <- vst(dds, blind=FALSE)
pcaData <- plotPCA(vsd, intgroup=c("condition"), returnData=TRUE)
percentVar <- round(100 * attr(pcaData, "percentVar"))

p2 <- ggplot(pcaData, aes(PC1, PC2, color=condition)) +
  geom_point(size=3) +
  xlab(paste0("PC1: ",percentVar[1],"% variance")) +
  ylab(paste0("PC2: ",percentVar[2],"% variance")) + 
  coord_fixed()

png("results_pca-plot.png")
  print(p2)
dev.off()
  




